@@ -99,11 +99,11 @@ def rotation_matrix_components(axis: Any,
             >>> rotated = np.array([a*oi+b*oj+c*ok, d*oi+e*oj+f*ok, g*oi+h*oj+i*ok]).T
             >>> print(rotated.shape)
             (4, 3)
-            >>> print(rotated)
-            [[ 7.07106781e-01  7.07106781e-01  0.00000000e+00]
-             [ 2.22044605e-16  1.00000000e+00  0.00000000e+00]
-             [ 7.07106781e-01  0.00000000e+00 -7.07106781e-01]
-             [ 2.22044605e-16  0.00000000e+00 -1.00000000e+00]]
+            >>> print(np.allclose(rotated, np.array([[ 7.07106781e-01,  7.07106781e-01,  0.00000000e+00],
+            ...                                      [ 2.22044605e-16,  1.00000000e+00,  0.00000000e+00],
+            ...                                      [ 7.07106781e-01,  0.00000000e+00, -7.07106781e-01],
+            ...                                      [ 2.22044605e-16,  0.00000000e+00, -1.00000000e+00]])))
+            True
 
     """
     
